# constallation-vpc
## Version 0.2.1a0
### **<span style="color:red;">Warning | Do Not Use for anything important</span>**
**The version _0.2.1a0 is a package from the alpha stages and also pre-release** and has **undergone very minimal testing.** This version was built on `08/12/2024` Please use something more modern and closer to latest as this package is not secure for any actual use and its release serves archival means. 

***
### Changelist
- #### **<span style="color:red;">0.2.1a0</span>**
  - Handle The Following AWS CLI Error Codes
      - `DependencyViolation`
      - `InvalidRouteTableAssociationID.NotFound`